# pkgconf can optionally act as pkgconfig as well
%bcond_without pkgconfig_compat

# Mageia's configure macro needs to be overridden until
# the configure macros are unified.
# See: https://bugs.mageia.org/show_bug.cgi?id=19902
%if 0%{?mageia}
%{?configure2_5x:%global configure %configure2_5x}
%endif

# kyua and atf-tests aren't packaged in Mageia,
# so the tests will be disabled for them
%if 0%{?mageia}
%bcond_with check
%else
%bcond_without check
%endif

Name:           pkgconf
Version:        1.1.0
Release:        1%{?dist}
Summary:        A package compiler and linker metadata toolkit

License:        ISC
URL:            http://www.pkgconf.org/
Source0:        https://distfiles.dereferenced.org/%{name}/%{name}-%{version}.tar.xz

BuildRequires:  gcc, make

%if %{with check}
# For unit tests
BuildRequires:  /usr/bin/kyua
BuildRequires:  atf-tests
%endif

Requires:       %{name}-libs%{?_isa} = %{version}-%{release}

# FIXME: Make this not conflict with pkgconfig!
Recommends:       %{name}-m4 = %{version}-%{release}

%description
pkgconf is a program which helps to configure compiler and linker flags
for development frameworks. It is similar to pkg-config from freedesktop.org.

%package libs
Summary:        Libraries for %{name}

%description libs
This package provides libraries for applications to use the functionality
of %{name}.

%package static
Summary:        Static link library for %{name}
Requires:       %{name}-devel%{?_isa} = %{version}-%{release}

%description static
This package provides the link library for linking %{name} statically
into an application.

%package devel
Summary:        Development files for %{name}
Requires:       %{name}-libs%{?_isa} = %{version}-%{release}

%description devel
This package provides files necessary for developing applications
to use functionality in %{name}.

%package m4
Summary:        m4 macros for pkgconf
License:        GPLv2+
BuildArch:      noarch
# FIXME: We don't want this to be permanent
Conflicts:      pkgconfig

%description m4
This package includes m4 macros used to support
PKG_CHECK_MODULES when using pkgconf with autotools.

%if %{with pkgconfig_compat}
%package pkg-config
Summary:        Shim to provide /usr/bin/pkg-config
Conflicts:      pkgconfig
Provides:       pkgconfig = 0.29.1
Provides:       pkgconfig%{?_isa} = 0.29.1
#Provides:       pkgconfig(pkg-config) = 0.29.1
Provides:       pkg-config = 0.29.1
Provides:       pkg-config%{?_isa} = 0.29.1
Provides:       /bin/pkg-config
Provides:       %{_bindir}/pkg-config
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       %{name}-m4 = %{version}-%{release}

%description pkg-config
This package provides the shim links for pkgconf to be automatically
used in place of pkgconfig.

This is useful when bootstrapping new architectures where you wish
to avoid the circular dependency with glib2 and pkgconfig when
building from source.
%endif

%prep
%autosetup


%build
%configure \
           --with-pkg-config-dir=%{_libdir}/pkgconfig:%{_datadir}/pkgconfig \
           --with-system-includedir=%{_includedir} \
           --with-system-libdir=%{_libdir}
%make_build

%if %{with check}
%check
make check
%endif

%install
%make_install

find %{buildroot} -name "*.la" -delete

%if %{with pkgconfig_compat}
ln -sf pkgconf %{buildroot}%{_bindir}/pkg-config
ln -sf pkgconf %{buildroot}%{_bindir}/%{_target_platform}-pkg-config
%endif

# Mageia has file triggers for this
%if ! 0%{?mageia}
%post libs -p /sbin/ldconfig

%postun libs -p /sbin/ldconfig
%endif

%files
%license COPYING
%doc README.md AUTHORS NEWS
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1.*

%files libs
%license COPYING
%{_libdir}/lib%{name}*.so.*

%files static
%license COPYING
%{_libdir}/lib%{name}*.a

%files devel
%{_libdir}/lib%{name}*.so
%{_includedir}/%{name}
%{_libdir}/pkgconfig/lib%{name}.pc

%files m4
%{_datadir}/aclocal/pkg.m4

%if %{with pkgconfig_compat}
%files pkg-config
%{_bindir}/pkg-config
%{_bindir}/%{_target_platform}-pkg-config
%endif

%changelog
* Sat Dec 31 2016 Neal Gompa <ngompa13@gmail.com> - 1.1.0-1
- Upgrade to 1.1.0
- Enable libpkgconf libraries now that they are ABI+API stable

* Tue Oct 25 2016 Neal Gompa <ngompa13@gmail.com> - 1.0.2-2
- Fix configure call for Mageia

* Tue Oct 25 2016 Neal Gompa <ngompa13@gmail.com> - 1.0.2-1
- Upgrade to 1.0.2

* Fri Aug 26 2016 Neal Gompa <ngompa13@gmail.com> - 1.0.1-2
- Add subpackage for providing pkg-config shim
- Enable tests

* Thu Aug 25 2016 Neal Gompa <ngompa13@gmail.com> - 1.0.1-1
- Upgrade to 1.0.1

* Wed Aug 24 2016 Neal Gompa <ngompa13@gmail.com> - 1-1
- Initial packaging
